==> frma_1.4.0.zip: frma/doc/frma.R <==
###################################################
### chunk number 1: 
###################################################
#line 68 "frma.Rnw"
library(frma)


###################################################
### chunk number 2: 
###################################################
#line 72 "frma.Rnw"
library(frmaExampleData)
data(AffyBatchExample)
object <- frma(AffyBatchExample, summarize="median_polish")


###################################################
### chunk number 3: 
###################################################
#line 92 "frma.Rnw"
library(frma)


###################################################
### chunk number 4: 
###################################################
#line 96 "frma.Rnw"
library(frmaExampleData)
data(AffyBatchExample)
object <- frma(AffyBatchExample, summarize="robust_weighted_average")


###################################################
### chunk number 5: 
###################################################
#line 116 "frma.Rnw"
##library(frma)


###################################################
### chunk number 6: 
###################################################
#line 120 "frma.Rnw"
##library(frmaExampleData)
##data(AffyBatchExample)
##object <- frma(AffyBatchExample, summarize="random_effect")


###################################################
### chunk number 7: 
###################################################
#line 129 "frma.Rnw"
e <- exprs(object)


###################################################
### chunk number 8: 
###################################################
#line 233 "frma.Rnw"
library(frma)


###################################################
### chunk number 9: 
###################################################
#line 237 "frma.Rnw"
library(frmaExampleData)
data(AffyBatchExample)
object <- frma(AffyBatchExample)


###################################################
### chunk number 10: 
###################################################
#line 243 "frma.Rnw"
bc <- barcode(object)

==> frma_1.18.0.zip: frma/doc/frma.R <==
### R code from vignette source 'frma.Rnw'

###################################################
### code chunk number 1: frma.Rnw:67-68
###################################################
library(frma)


###################################################
### code chunk number 2: frma.Rnw:71-74
###################################################
library(frmaExampleData)
data(AffyBatchExample)
object <- frma(AffyBatchExample, summarize="median_polish")


###################################################
### code chunk number 3: frma.Rnw:91-92
###################################################
library(frma)


###################################################
### code chunk number 4: frma.Rnw:95-98
###################################################
library(frmaExampleData)
data(AffyBatchExample)
object <- frma(AffyBatchExample, summarize="robust_weighted_average")


###################################################
### code chunk number 5: frma.Rnw:115-116
###################################################
##library(frma)


###################################################
### code chunk number 6: frma.Rnw:119-122
###################################################
##library(frmaExampleData)
##data(AffyBatchExample)
##object <- frma(AffyBatchExample, summarize="random_effect")


###################################################
### code chunk number 7: frma.Rnw:128-129
###################################################
e <- exprs(object)


###################################################
### code chunk number 8: frma.Rnw:232-233
###################################################
library(frma)


###################################################
### code chunk number 9: frma.Rnw:236-239
###################################################
library(frmaExampleData)
data(AffyBatchExample)
object <- frma(AffyBatchExample)


###################################################
### code chunk number 10: frma.Rnw:242-243
###################################################
bc <- barcode(object)
